Request

#[non_exhaustive]
pub enum Request { Receive { mime_type: String, fd: OwnedFd, }, Destroy, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Receive

request that the data is transferred

To transfer the contents of the primary selection clipboard, the client issues this request and indicates the mime type that it wants to receive. The transfer happens through the passed file descriptor (typically created with the pipe system call). The source client writes the data in the mime type representation requested and then closes the file descriptor.

The receiving client reads from the read end of the pipe until EOF and closes its end, at which point the transfer is complete.

Fields

mime_type: String


Destroy

destroy the primary selection offer

Destroy the primary selection offer.

This is a destructor, once received this object cannot be used any longer.

Implementations

Source

impl Request

pub fn opcode(&self) -> u16

Get the opcode number of this message